@@ -2,6 +2,7 @@ import io
 from concurrent.futures import ThreadPoolExecutor
 
 from .feature import Feature
+from .point_in_time_group import PointInTimeGroup
 from .return_class import AbstractApiClass
 
 
@@ -12,6 +13,7 @@ class FeatureGroupVersion(AbstractApiClass):
         Args:
             client (ApiClient): An authenticated API Client instance
             featureGroupVersion (str): The unique identifier for this version of feature group.
+            featureGroupId (str): 
             sql (str): The sql definition creating this feature group.
             sourceTables (list of string): The source tables for this feature group.
             createdAt (str): The timestamp at which the feature group was created.
@@ -21,11 +23,13 @@ class FeatureGroupVersion(AbstractApiClass):
             cpuSize (str): Cpu size specified for the python feature group.
             memory (int): Memory in GB specified for the python feature group.
             features (Feature): List of features.
+            pointInTimeGroups (PointInTimeGroup): List of Point In Time Groups
     """
 
-    def __init__(self, client, featureGroupVersion=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, features={}):
+    def __init__(self, client, featureGroupVersion=None, featureGroupId=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, features={}, pointInTimeGroups={}):
         super().__init__(client, featureGroupVersion)
         self.feature_group_version = featureGroupVersion
+        self.feature_group_id = featureGroupId
         self.sql = sql
         self.source_tables = sourceTables
         self.created_at = createdAt
@@ -35,9 +39,11 @@ class FeatureGroupVersion(AbstractApiClass):
         self.cpu_size = cpuSize
         self.memory = memory
         self.features = client._build_class(Feature, features)
+        self.point_in_time_groups = client._build_class(
+            PointInTimeGroup, pointInTimeGroups)
 
     def __repr__(self):
-        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  features={repr(self.features)})"
+        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  feature_group_id={repr(self.feature_group_id)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  features={repr(self.features)},\n  point_in_time_groups={repr(self.point_in_time_groups)})"
 
     def to_dict(self):
         """
@@ -46,7 +52,7 @@ class FeatureGroupVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_version': self.feature_group_version, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'features': self._get_attribute_as_dict(self.features)}
+        return {'feature_group_version': self.feature_group_version, 'feature_group_id': self.feature_group_id, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'features': self._get_attribute_as_dict(self.features), 'point_in_time_groups': self._get_attribute_as_dict(self.point_in_time_groups)}
 
     def export_to_file_connector(self, location: str, export_file_format: str, overwrite: bool = False):
         """
